@@ -3,7 +3,6 @@ use Encode;
 use Storable qw(dclone);
 sub Webqq::Client::_send_message{
     my($self,$msg) = @_;
-    my $msg_clone = dclone($msg);
     #将整个hash从UTF8还原为unicode
     my $ua = $self->{asyn_ua};
     my $send_message_callback = $msg->{cb} || $self->{on_send_message};
@@ -27,21 +26,22 @@ sub Webqq::Client::_send_message{
     my @headers = $self->{type} eq 'webqq'? (Referer=>'http://d.web2.qq.com/proxy.html?v=20110331002&callback=1&id=3')
                 :                           (Referer=>'http://d.web2.qq.com/proxy.html?v=20130916001&callback=1&id=2')
                 ;
-    my $content = [decode("utf8",$msg_clone->{content}),"",[]];
+    my $content = [decode("utf8",$msg->{content}),"",[]];
     my %s = (
-        to      => $msg_clone->{to_uin},
+        to      => $msg->{to_uin},
         face    => $self->{qq_database}{user}{face} || 570,
         content => JSON->new->utf8->encode($content),
-        msg_id  =>  $msg_clone->{msg_id},
+        msg_id  =>  $msg->{msg_id},
         clientid => $self->{qq_param}{clientid},
         psessionid  => $self->{qq_param}{psessionid},
     );
+    $s{content} = decode("utf8",$s{content}); 
     
     if($self->{type} eq 'smartqq'){
         $s{face} = $self->{qq_database}{user}{face} || "591";
     }
     my $post_content = [
-        r           =>  decode("utf8",JSON->new->encode(\%s)),
+        r           =>  JSON->new->utf8->encode(\%s),
     ];
     if($self->{type} eq 'webqq'){
         push @$post_content,(
